Function dbs_boot::get_kernel_start
source · [−]pub fn get_kernel_start() -> u64Expand description
Returns the memory address where the kernel could be loaded.
pub fn get_kernel_start() -> u64Returns the memory address where the kernel could be loaded.